from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
NAME_FIELD_NUMBER: _ClassVar[int]
name: _descriptor.FieldDescriptor
MESSAGE_ENCODING_FIELD_NUMBER: _ClassVar[int]
message_encoding: _descriptor.FieldDescriptor
ENCODING_FIELD_NUMBER: _ClassVar[int]
encoding: _descriptor.FieldDescriptor
FIELD_NAME_FIELD_NUMBER: _ClassVar[int]
field_name: _descriptor.FieldDescriptor
DONT_OMITEMPTY_FIELD_NUMBER: _ClassVar[int]
dont_omitempty: _descriptor.FieldDescriptor
ONEOF_NAME_FIELD_NUMBER: _ClassVar[int]
oneof_name: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as dydxprotocol_dot_perpetuals_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%dydxprotocol/perpetuals/genesis.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\x1a$dydxprotocol/perpetuals/params.proto\"\xca\x01\n\x0cGenesisState\x12<\n\nperpetuals\x18\x01 \x03(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\x12\x45\n\x0fliquidity_tiers\x18\x02 \x03(\x0b\x32&.dydxprotocol.perpetuals.LiquidityTierB\x04\xc8\xde\x1f\x00\x12\x35\n\x06params\x18\x03 \x01(\x0b\x32\x1f.dydxprotocol.perpetuals.ParamsB\x04\xc8\xde\x1f\x00\x42>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_GENESISSTATE'].fields_by_name['perpetuals']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['perpetuals']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['liquidity_tiers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['liquidity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=168
  _globals['_GENESISSTATE']._serialized_end=370
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ValidatorSigningInfo(_message.Message):
    __slots__ = ("address", "start_height", "index_offset", "jailed_until", "tombstoned", "missed_blocks_counter")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    START_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INDEX_OFFSET_FIELD_NUMBER: _ClassVar[int]
    JAILED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    TOMBSTONED_FIELD_NUMBER: _ClassVar[int]
    MISSED_BLOCKS_COUNTER_FIELD_NUMBER: _ClassVar[int]
    address: str
    start_height: int
    index_offset: int
    jailed_until: _timestamp_pb2.Timestamp
    tombstoned: bool
    missed_blocks_counter: int
    def __init__(self, address: _Optional[str] = ..., start_height: _Optional[int] = ..., index_offset: _Optional[int] = ..., jailed_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., tombstoned: bool = ..., missed_blocks_counter: _Optional[int] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("signed_blocks_window", "min_signed_per_window", "downtime_jail_duration", "slash_fraction_double_sign", "slash_fraction_downtime")
    SIGNED_BLOCKS_WINDOW_FIELD_NUMBER: _ClassVar[int]
    MIN_SIGNED_PER_WINDOW_FIELD_NUMBER: _ClassVar[int]
    DOWNTIME_JAIL_DURATION_FIELD_NUMBER: _ClassVar[int]
    SLASH_FRACTION_DOUBLE_SIGN_FIELD_NUMBER: _ClassVar[int]
    SLASH_FRACTION_DOWNTIME_FIELD_NUMBER: _ClassVar[int]
    signed_blocks_window: int
    min_signed_per_window: bytes
    downtime_jail_duration: _duration_pb2.Duration
    slash_fraction_double_sign: bytes
    slash_fraction_downtime: bytes
    def __init__(self, signed_blocks_window: _Optional[int] = ..., min_signed_per_window: _Optional[bytes] = ..., downtime_jail_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., slash_fraction_double_sign: _Optional[bytes] = ..., slash_fraction_downtime: _Optional[bytes] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModuleOptions(_message.Message):
    __slots__ = ("tx", "query")
    TX_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    tx: ServiceCommandDescriptor
    query: ServiceCommandDescriptor
    def __init__(self, tx: _Optional[_Union[ServiceCommandDescriptor, _Mapping]] = ..., query: _Optional[_Union[ServiceCommandDescriptor, _Mapping]] = ...) -> None: ...

class ServiceCommandDescriptor(_message.Message):
    __slots__ = ("service", "rpc_command_options", "sub_commands")
    class SubCommandsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ServiceCommandDescriptor
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ServiceCommandDescriptor, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    RPC_COMMAND_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    SUB_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    service: str
    rpc_command_options: _containers.RepeatedCompositeFieldContainer[RpcCommandOptions]
    sub_commands: _containers.MessageMap[str, ServiceCommandDescriptor]
    def __init__(self, service: _Optional[str] = ..., rpc_command_options: _Optional[_Iterable[_Union[RpcCommandOptions, _Mapping]]] = ..., sub_commands: _Optional[_Mapping[str, ServiceCommandDescriptor]] = ...) -> None: ...

class RpcCommandOptions(_message.Message):
    __slots__ = ("rpc_method", "use", "long", "short", "example", "alias", "suggest_for", "deprecated", "version", "flag_options", "positional_args", "skip")
    class FlagOptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: FlagOptions
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[FlagOptions, _Mapping]] = ...) -> None: ...
    RPC_METHOD_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    LONG_FIELD_NUMBER: _ClassVar[int]
    SHORT_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    SUGGEST_FOR_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FLAG_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    POSITIONAL_ARGS_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    rpc_method: str
    use: str
    long: str
    short: str
    example: str
    alias: _containers.RepeatedScalarFieldContainer[str]
    suggest_for: _containers.RepeatedScalarFieldContainer[str]
    deprecated: str
    version: str
    flag_options: _containers.MessageMap[str, FlagOptions]
    positional_args: _containers.RepeatedCompositeFieldContainer[PositionalArgDescriptor]
    skip: bool
    def __init__(self, rpc_method: _Optional[str] = ..., use: _Optional[str] = ..., long: _Optional[str] = ..., short: _Optional[str] = ..., example: _Optional[str] = ..., alias: _Optional[_Iterable[str]] = ..., suggest_for: _Optional[_Iterable[str]] = ..., deprecated: _Optional[str] = ..., version: _Optional[str] = ..., flag_options: _Optional[_Mapping[str, FlagOptions]] = ..., positional_args: _Optional[_Iterable[_Union[PositionalArgDescriptor, _Mapping]]] = ..., skip: bool = ...) -> None: ...

class FlagOptions(_message.Message):
    __slots__ = ("name", "shorthand", "usage", "default_value", "deprecated", "shorthand_deprecated", "hidden")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SHORTHAND_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    SHORTHAND_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    name: str
    shorthand: str
    usage: str
    default_value: str
    deprecated: str
    shorthand_deprecated: str
    hidden: bool
    def __init__(self, name: _Optional[str] = ..., shorthand: _Optional[str] = ..., usage: _Optional[str] = ..., default_value: _Optional[str] = ..., deprecated: _Optional[str] = ..., shorthand_deprecated: _Optional[str] = ..., hidden: bool = ...) -> None: ...

class PositionalArgDescriptor(_message.Message):
    __slots__ = ("proto_field", "varargs")
    PROTO_FIELD_FIELD_NUMBER: _ClassVar[int]
    VARARGS_FIELD_NUMBER: _ClassVar[int]
    proto_field: str
    varargs: bool
    def __init__(self, proto_field: _Optional[str] = ..., varargs: bool = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as _block_rate_limit_config_pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as _equity_tier_limit_config_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as _matches_pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as _liquidations_config_pb2
from v4_proto.dydxprotocol.clob import mev_pb2 as _mev_pb2
from v4_proto.dydxprotocol.indexer.off_chain_updates import off_chain_updates_pb2 as _off_chain_updates_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGetClobPairRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryClobPairResponse(_message.Message):
    __slots__ = ("clob_pair",)
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    clob_pair: _clob_pair_pb2.ClobPair
    def __init__(self, clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ...) -> None: ...

class QueryAllClobPairRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryClobPairAllResponse(_message.Message):
    __slots__ = ("clob_pair", "pagination")
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    clob_pair: _containers.RepeatedCompositeFieldContainer[_clob_pair_pb2.ClobPair]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, clob_pair: _Optional[_Iterable[_Union[_clob_pair_pb2.ClobPair, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class MevNodeToNodeCalculationRequest(_message.Message):
    __slots__ = ("block_proposer_matches", "validator_mev_metrics")
    BLOCK_PROPOSER_MATCHES_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_MEV_METRICS_FIELD_NUMBER: _ClassVar[int]
    block_proposer_matches: _mev_pb2.ValidatorMevMatches
    validator_mev_metrics: _mev_pb2.MevNodeToNodeMetrics
    def __init__(self, block_proposer_matches: _Optional[_Union[_mev_pb2.ValidatorMevMatches, _Mapping]] = ..., validator_mev_metrics: _Optional[_Union[_mev_pb2.MevNodeToNodeMetrics, _Mapping]] = ...) -> None: ...

class MevNodeToNodeCalculationResponse(_message.Message):
    __slots__ = ("results",)
    class MevAndVolumePerClob(_message.Message):
        __slots__ = ("clob_pair_id", "mev", "volume")
        CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
        MEV_FIELD_NUMBER: _ClassVar[int]
        VOLUME_FIELD_NUMBER: _ClassVar[int]
        clob_pair_id: int
        mev: float
        volume: int
        def __init__(self, clob_pair_id: _Optional[int] = ..., mev: _Optional[float] = ..., volume: _Optional[int] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[MevNodeToNodeCalculationResponse.MevAndVolumePerClob]
    def __init__(self, results: _Optional[_Iterable[_Union[MevNodeToNodeCalculationResponse.MevAndVolumePerClob, _Mapping]]] = ...) -> None: ...

class QueryEquityTierLimitConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryEquityTierLimitConfigurationResponse(_message.Message):
    __slots__ = ("equity_tier_limit_config",)
    EQUITY_TIER_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    equity_tier_limit_config: _equity_tier_limit_config_pb2.EquityTierLimitConfiguration
    def __init__(self, equity_tier_limit_config: _Optional[_Union[_equity_tier_limit_config_pb2.EquityTierLimitConfiguration, _Mapping]] = ...) -> None: ...

class QueryBlockRateLimitConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryBlockRateLimitConfigurationResponse(_message.Message):
    __slots__ = ("block_rate_limit_config",)
    BLOCK_RATE_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    block_rate_limit_config: _block_rate_limit_config_pb2.BlockRateLimitConfiguration
    def __init__(self, block_rate_limit_config: _Optional[_Union[_block_rate_limit_config_pb2.BlockRateLimitConfiguration, _Mapping]] = ...) -> None: ...

class QueryStatefulOrderRequest(_message.Message):
    __slots__ = ("order_id",)
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    order_id: _order_pb2.OrderId
    def __init__(self, order_id: _Optional[_Union[_order_pb2.OrderId, _Mapping]] = ...) -> None: ...

class QueryStatefulOrderResponse(_message.Message):
    __slots__ = ("order_placement", "fill_amount", "triggered")
    ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TRIGGERED_FIELD_NUMBER: _ClassVar[int]
    order_placement: _order_pb2.LongTermOrderPlacement
    fill_amount: int
    triggered: bool
    def __init__(self, order_placement: _Optional[_Union[_order_pb2.LongTermOrderPlacement, _Mapping]] = ..., fill_amount: _Optional[int] = ..., triggered: bool = ...) -> None: ...

class QueryLiquidationsConfigurationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryLiquidationsConfigurationResponse(_message.Message):
    __slots__ = ("liquidations_config",)
    LIQUIDATIONS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    liquidations_config: _liquidations_config_pb2.LiquidationsConfig
    def __init__(self, liquidations_config: _Optional[_Union[_liquidations_config_pb2.LiquidationsConfig, _Mapping]] = ...) -> None: ...

class StreamOrderbookUpdatesRequest(_message.Message):
    __slots__ = ("clob_pair_id",)
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    clob_pair_id: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, clob_pair_id: _Optional[_Iterable[int]] = ...) -> None: ...

class StreamOrderbookUpdatesResponse(_message.Message):
    __slots__ = ("updates",)
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    updates: _containers.RepeatedCompositeFieldContainer[StreamUpdate]
    def __init__(self, updates: _Optional[_Iterable[_Union[StreamUpdate, _Mapping]]] = ...) -> None: ...

class StreamUpdate(_message.Message):
    __slots__ = ("orderbook_update", "order_fill", "block_height", "exec_mode")
    ORDERBOOK_UPDATE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FILL_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    EXEC_MODE_FIELD_NUMBER: _ClassVar[int]
    orderbook_update: StreamOrderbookUpdate
    order_fill: StreamOrderbookFill
    block_height: int
    exec_mode: int
    def __init__(self, orderbook_update: _Optional[_Union[StreamOrderbookUpdate, _Mapping]] = ..., order_fill: _Optional[_Union[StreamOrderbookFill, _Mapping]] = ..., block_height: _Optional[int] = ..., exec_mode: _Optional[int] = ...) -> None: ...

class StreamOrderbookUpdate(_message.Message):
    __slots__ = ("updates", "snapshot")
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    updates: _containers.RepeatedCompositeFieldContainer[_off_chain_updates_pb2.OffChainUpdateV1]
    snapshot: bool
    def __init__(self, updates: _Optional[_Iterable[_Union[_off_chain_updates_pb2.OffChainUpdateV1, _Mapping]]] = ..., snapshot: bool = ...) -> None: ...

class StreamOrderbookFill(_message.Message):
    __slots__ = ("clob_match", "orders", "fill_amounts")
    CLOB_MATCH_FIELD_NUMBER: _ClassVar[int]
    ORDERS_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNTS_FIELD_NUMBER: _ClassVar[int]
    clob_match: _matches_pb2.ClobMatch
    orders: _containers.RepeatedCompositeFieldContainer[_order_pb2.Order]
    fill_amounts: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, clob_match: _Optional[_Union[_matches_pb2.ClobMatch, _Mapping]] = ..., orders: _Optional[_Iterable[_Union[_order_pb2.Order, _Mapping]]] = ..., fill_amounts: _Optional[_Iterable[int]] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.feetiers import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryPerpetualFeeParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryPerpetualFeeParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.PerpetualFeeParams
    def __init__(self, params: _Optional[_Union[_params_pb2.PerpetualFeeParams, _Mapping]] = ...) -> None: ...

class QueryUserFeeTierRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryUserFeeTierResponse(_message.Message):
    __slots__ = ("index", "tier")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TIER_FIELD_NUMBER: _ClassVar[int]
    index: int
    tier: _params_pb2.PerpetualFeeTier
    def __init__(self, index: _Optional[int] = ..., tier: _Optional[_Union[_params_pb2.PerpetualFeeTier, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/perpetuals/params.proto\x12\x17\x64ydxprotocol.perpetuals\"x\n\x06Params\x12%\n\x1d\x66unding_rate_clamp_factor_ppm\x18\x01 \x01(\r\x12%\n\x1dpremium_vote_clamp_factor_ppm\x18\x02 \x01(\r\x12 \n\x18min_num_votes_per_sample\x18\x03 \x01(\rB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_PARAMS']._serialized_start=65
  _globals['_PARAMS']._serialized_end=185
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/v1beta1/commit_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/store/v1beta1/commit_info.proto\x12\x14\x63osmos.store.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x01\n\nCommitInfo\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12:\n\x0bstore_infos\x18\x02 \x03(\x0b\x32\x1f.cosmos.store.v1beta1.StoreInfoB\x04\xc8\xde\x1f\x00\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"R\n\tStoreInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\tcommit_id\x18\x02 \x01(\x0b\x32\x1e.cosmos.store.v1beta1.CommitIDB\x04\xc8\xde\x1f\x00\"/\n\x08\x43ommitID\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12\x0c\n\x04hash\x18\x02 \x01(\x0c:\x04\x98\xa0\x1f\x00\x42\x1aZ\x18\x63osmossdk.io/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.v1beta1.commit_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030cosmossdk.io/store/types'
  _globals['_COMMITINFO'].fields_by_name['store_infos']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['store_infos']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['timestamp']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STOREINFO'].fields_by_name['commit_id']._loaded_options = None
  _globals['_STOREINFO'].fields_by_name['commit_id']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITID']._loaded_options = None
  _globals['_COMMITID']._serialized_options = b'\230\240\037\000'
  _globals['_COMMITINFO']._serialized_start=120
  _globals['_COMMITINFO']._serialized_end=266
  _globals['_STOREINFO']._serialized_start=268
  _globals['_STOREINFO']._serialized_end=350
  _globals['_COMMITID']._serialized_start=352
  _globals['_COMMITID']._serialized_end=399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/app/runtime/v1alpha1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(cosmos/app/runtime/v1alpha1/module.proto\x12\x1b\x63osmos.app.runtime.v1alpha1\x1a cosmos/app/v1alpha1/module.proto\"\xd4\x02\n\x06Module\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x65gin_blockers\x18\x02 \x03(\t\x12\x14\n\x0c\x65nd_blockers\x18\x03 \x03(\t\x12\x14\n\x0cinit_genesis\x18\x04 \x03(\t\x12\x16\n\x0e\x65xport_genesis\x18\x05 \x03(\t\x12H\n\x13override_store_keys\x18\x06 \x03(\x0b\x32+.cosmos.app.runtime.v1alpha1.StoreKeyConfig\x12\x18\n\x10order_migrations\x18\x07 \x03(\t\x12\x14\n\x0cprecommiters\x18\x08 \x03(\t\x12\x1d\n\x15prepare_check_staters\x18\t \x03(\t:C\xba\xc0\x96\xda\x01=\n$github.com/cosmos/cosmos-sdk/runtime\x12\x15\n\x13\x63osmos.app.v1alpha1\";\n\x0eStoreKeyConfig\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x14\n\x0ckv_store_key\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.runtime.v1alpha1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001=\n$github.com/cosmos/cosmos-sdk/runtime\022\025\n\023cosmos.app.v1alpha1'
  _globals['_MODULE']._serialized_start=108
  _globals['_MODULE']._serialized_end=448
  _globals['_STOREKEYCONFIG']._serialized_start=450
  _globals['_STOREKEYCONFIG']._serialized_end=509
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventParams(_message.Message):
    __slots__ = ("denom", "eth_chain_id", "eth_address")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    ETH_CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    ETH_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    denom: str
    eth_chain_id: int
    eth_address: str
    def __init__(self, denom: _Optional[str] = ..., eth_chain_id: _Optional[int] = ..., eth_address: _Optional[str] = ...) -> None: ...

class ProposeParams(_message.Message):
    __slots__ = ("max_bridges_per_block", "propose_delay_duration", "skip_rate_ppm", "skip_if_block_delayed_by_duration")
    MAX_BRIDGES_PER_BLOCK_FIELD_NUMBER: _ClassVar[int]
    PROPOSE_DELAY_DURATION_FIELD_NUMBER: _ClassVar[int]
    SKIP_RATE_PPM_FIELD_NUMBER: _ClassVar[int]
    SKIP_IF_BLOCK_DELAYED_BY_DURATION_FIELD_NUMBER: _ClassVar[int]
    max_bridges_per_block: int
    propose_delay_duration: _duration_pb2.Duration
    skip_rate_ppm: int
    skip_if_block_delayed_by_duration: _duration_pb2.Duration
    def __init__(self, max_bridges_per_block: _Optional[int] = ..., propose_delay_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., skip_rate_ppm: _Optional[int] = ..., skip_if_block_delayed_by_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class SafetyParams(_message.Message):
    __slots__ = ("is_disabled", "delay_blocks")
    IS_DISABLED_FIELD_NUMBER: _ClassVar[int]
    DELAY_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    is_disabled: bool
    delay_blocks: int
    def __init__(self, is_disabled: bool = ..., delay_blocks: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as dydxprotocol_dot_perpetuals_dot_params__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/perpetuals/tx.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a$dydxprotocol/perpetuals/params.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\"\x91\x01\n\x12MsgCreatePerpetual\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12>\n\x06params\x18\x02 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgCreatePerpetualResponse\"\x98\x01\n\x13MsgSetLiquidityTier\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x44\n\x0eliquidity_tier\x18\x02 \x01(\x0b\x32&.dydxprotocol.perpetuals.LiquidityTierB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1d\n\x1bMsgSetLiquidityTierResponse\"\xa1\x01\n\x18MsgUpdatePerpetualParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x10perpetual_params\x18\x02 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\"\n MsgUpdatePerpetualParamsResponse\";\n\x0e\x46undingPremium\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x13\n\x0bpremium_ppm\x18\x02 \x01(\x05\"R\n\x12MsgAddPremiumVotes\x12<\n\x05votes\x18\x01 \x03(\x0b\x32\'.dydxprotocol.perpetuals.FundingPremiumB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aMsgAddPremiumVotesResponse\"\x85\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x06params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.perpetuals.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xdb\x04\n\x03Msg\x12s\n\x0f\x41\x64\x64PremiumVotes\x12+.dydxprotocol.perpetuals.MsgAddPremiumVotes\x1a\x33.dydxprotocol.perpetuals.MsgAddPremiumVotesResponse\x12s\n\x0f\x43reatePerpetual\x12+.dydxprotocol.perpetuals.MsgCreatePerpetual\x1a\x33.dydxprotocol.perpetuals.MsgCreatePerpetualResponse\x12v\n\x10SetLiquidityTier\x12,.dydxprotocol.perpetuals.MsgSetLiquidityTier\x1a\x34.dydxprotocol.perpetuals.MsgSetLiquidityTierResponse\x12\x85\x01\n\x15UpdatePerpetualParams\x12\x31.dydxprotocol.perpetuals.MsgUpdatePerpetualParams\x1a\x39.dydxprotocol.perpetuals.MsgUpdatePerpetualParamsResponse\x12j\n\x0cUpdateParams\x12(.dydxprotocol.perpetuals.MsgUpdateParams\x1a\x30.dydxprotocol.perpetuals.MsgUpdateParamsResponseB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['params']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEPERPETUAL']._loaded_options = None
  _globals['_MSGCREATEPERPETUAL']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['liquidity_tier']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER'].fields_by_name['liquidity_tier']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETLIQUIDITYTIER']._loaded_options = None
  _globals['_MSGSETLIQUIDITYTIER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['perpetual_params']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS'].fields_by_name['perpetual_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPERPETUALPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGADDPREMIUMVOTES'].fields_by_name['votes']._loaded_options = None
  _globals['_MSGADDPREMIUMVOTES'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEPERPETUAL']._serialized_start=215
  _globals['_MSGCREATEPERPETUAL']._serialized_end=360
  _globals['_MSGCREATEPERPETUALRESPONSE']._serialized_start=362
  _globals['_MSGCREATEPERPETUALRESPONSE']._serialized_end=390
  _globals['_MSGSETLIQUIDITYTIER']._serialized_start=393
  _globals['_MSGSETLIQUIDITYTIER']._serialized_end=545
  _globals['_MSGSETLIQUIDITYTIERRESPONSE']._serialized_start=547
  _globals['_MSGSETLIQUIDITYTIERRESPONSE']._serialized_end=576
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_start=579
  _globals['_MSGUPDATEPERPETUALPARAMS']._serialized_end=740
  _globals['_MSGUPDATEPERPETUALPARAMSRESPONSE']._serialized_start=742
  _globals['_MSGUPDATEPERPETUALPARAMSRESPONSE']._serialized_end=776
  _globals['_FUNDINGPREMIUM']._serialized_start=778
  _globals['_FUNDINGPREMIUM']._serialized_end=837
  _globals['_MSGADDPREMIUMVOTES']._serialized_start=839
  _globals['_MSGADDPREMIUMVOTES']._serialized_end=921
  _globals['_MSGADDPREMIUMVOTESRESPONSE']._serialized_start=923
  _globals['_MSGADDPREMIUMVOTESRESPONSE']._serialized_end=951
  _globals['_MSGUPDATEPARAMS']._serialized_start=954
  _globals['_MSGUPDATEPARAMS']._serialized_end=1087
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1089
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1114
  _globals['_MSG']._serialized_start=1117
  _globals['_MSG']._serialized_end=1720
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.clob import order_pb2 as _order_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProcessProposerMatchesEvents(_message.Message):
    __slots__ = ("placed_long_term_order_ids", "expired_stateful_order_ids", "order_ids_filled_in_last_block", "placed_stateful_cancellation_order_ids", "removed_stateful_order_ids", "conditional_order_ids_triggered_in_last_block", "placed_conditional_order_ids", "block_height")
    PLACED_LONG_TERM_ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    EXPIRED_STATEFUL_ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    ORDER_IDS_FILLED_IN_LAST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    PLACED_STATEFUL_CANCELLATION_ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVED_STATEFUL_ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    CONDITIONAL_ORDER_IDS_TRIGGERED_IN_LAST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    PLACED_CONDITIONAL_ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    placed_long_term_order_ids: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    expired_stateful_order_ids: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    order_ids_filled_in_last_block: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    placed_stateful_cancellation_order_ids: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    removed_stateful_order_ids: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    conditional_order_ids_triggered_in_last_block: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    placed_conditional_order_ids: _containers.RepeatedCompositeFieldContainer[_order_pb2.OrderId]
    block_height: int
    def __init__(self, placed_long_term_order_ids: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., expired_stateful_order_ids: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., order_ids_filled_in_last_block: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., placed_stateful_cancellation_order_ids: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., removed_stateful_order_ids: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., conditional_order_ids_triggered_in_last_block: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., placed_conditional_order_ids: _Optional[_Iterable[_Union[_order_pb2.OrderId, _Mapping]]] = ..., block_height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/assets/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64ydxprotocol/assets/tx.proto\x12\x13\x64ydxprotocol.assets2\x05\n\x03MsgB:Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.assets.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/assets/types'
  _globals['_MSG']._serialized_start=53
  _globals['_MSG']._serialized_end=58
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/operation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.clob import matches_pb2 as dydxprotocol_dot_clob_dot_matches__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2
from v4_proto.dydxprotocol.clob import order_removals_pb2 as dydxprotocol_dot_clob_dot_order__removals__pb2
from v4_proto.dydxprotocol.clob import tx_pb2 as dydxprotocol_dot_clob_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/clob/operation.proto\x12\x11\x64ydxprotocol.clob\x1a\x1f\x64ydxprotocol/clob/matches.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\x1a&dydxprotocol/clob/order_removals.proto\x1a\x1a\x64ydxprotocol/clob/tx.proto\"\x9d\x02\n\tOperation\x12-\n\x05match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatchH\x00\x12\x46\n\x1ashort_term_order_placement\x18\x02 \x01(\x0b\x32 .dydxprotocol.clob.MsgPlaceOrderH\x00\x12J\n\x1dshort_term_order_cancellation\x18\x03 \x01(\x0b\x32!.dydxprotocol.clob.MsgCancelOrderH\x00\x12@\n\x1apreexisting_stateful_order\x18\x04 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdH\x00\x42\x0b\n\toperation\"\x93\x02\n\x11InternalOperation\x12-\n\x05match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatchH\x00\x12\x46\n\x1ashort_term_order_placement\x18\x02 \x01(\x0b\x32 .dydxprotocol.clob.MsgPlaceOrderH\x00\x12@\n\x1apreexisting_stateful_order\x18\x03 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdH\x00\x12\x38\n\rorder_removal\x18\x04 \x01(\x0b\x32\x1f.dydxprotocol.clob.OrderRemovalH\x00\x42\x0b\n\toperationB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.operation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_OPERATION']._serialized_start=189
  _globals['_OPERATION']._serialized_end=474
  _globals['_INTERNALOPERATION']._serialized_start=477
  _globals['_INTERNALOPERATION']._serialized_end=752
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/daemons/liquidation/liquidation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.clob import liquidations_pb2 as dydxprotocol_dot_clob_dot_liquidations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dydxprotocol/daemons/liquidation/liquidation.proto\x12 dydxprotocol.daemons.liquidation\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a$dydxprotocol/clob/liquidations.proto\"\xb5\x02\n\x1bLiquidateSubaccountsRequest\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\r\x12Q\n\x1bliquidatable_subaccount_ids\x18\x02 \x03(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12Q\n\x1bnegative_tnc_subaccount_ids\x18\x03 \x03(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12Z\n\x1dsubaccount_open_position_info\x18\x04 \x03(\x0b\x32-.dydxprotocol.clob.SubaccountOpenPositionInfoB\x04\xc8\xde\x1f\x00\"\x1e\n\x1cLiquidateSubaccountsResponse2\xac\x01\n\x12LiquidationService\x12\x95\x01\n\x14LiquidateSubaccounts\x12=.dydxprotocol.daemons.liquidation.LiquidateSubaccountsRequest\x1a>.dydxprotocol.daemons.liquidation.LiquidateSubaccountsResponseBCZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.liquidation.liquidation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/api'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['liquidatable_subaccount_ids']._loaded_options = None
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['liquidatable_subaccount_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['negative_tnc_subaccount_ids']._loaded_options = None
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['negative_tnc_subaccount_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['subaccount_open_position_info']._loaded_options = None
  _globals['_LIQUIDATESUBACCOUNTSREQUEST'].fields_by_name['subaccount_open_position_info']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_start=192
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_end=501
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_start=503
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_end=533
  _globals['_LIQUIDATIONSERVICE']._serialized_start=536
  _globals['_LIQUIDATIONSERVICE']._serialized_end=708
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as _perpetual_pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("perpetuals", "liquidity_tiers", "params")
    PERPETUALS_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIERS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    perpetuals: _containers.RepeatedCompositeFieldContainer[_perpetual_pb2.Perpetual]
    liquidity_tiers: _containers.RepeatedCompositeFieldContainer[_perpetual_pb2.LiquidityTier]
    params: _params_pb2.Params
    def __init__(self, perpetuals: _Optional[_Iterable[_Union[_perpetual_pb2.Perpetual, _Mapping]]] = ..., liquidity_tiers: _Optional[_Iterable[_Union[_perpetual_pb2.LiquidityTier, _Mapping]]] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos.crypto.hd.v1 import hd_pb2 as _hd_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Record(_message.Message):
    __slots__ = ("name", "pub_key", "local", "ledger", "multi", "offline")
    class Local(_message.Message):
        __slots__ = ("priv_key",)
        PRIV_KEY_FIELD_NUMBER: _ClassVar[int]
        priv_key: _any_pb2.Any
        def __init__(self, priv_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...
    class Ledger(_message.Message):
        __slots__ = ("path",)
        PATH_FIELD_NUMBER: _ClassVar[int]
        path: _hd_pb2.BIP44Params
        def __init__(self, path: _Optional[_Union[_hd_pb2.BIP44Params, _Mapping]] = ...) -> None: ...
    class Multi(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Offline(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    LEDGER_FIELD_NUMBER: _ClassVar[int]
    MULTI_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_FIELD_NUMBER: _ClassVar[int]
    name: str
    pub_key: _any_pb2.Any
    local: Record.Local
    ledger: Record.Ledger
    multi: Record.Multi
    offline: Record.Offline
    def __init__(self, name: _Optional[str] = ..., pub_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., local: _Optional[_Union[Record.Local, _Mapping]] = ..., ledger: _Optional[_Union[Record.Ledger, _Mapping]] = ..., multi: _Optional[_Union[Record.Multi, _Mapping]] = ..., offline: _Optional[_Union[Record.Offline, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/v1alpha1/schema.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/orm/v1alpha1/schema.proto\x12\x13\x63osmos.orm.v1alpha1\x1a google/protobuf/descriptor.proto\"\xde\x01\n\x16ModuleSchemaDescriptor\x12J\n\x0bschema_file\x18\x01 \x03(\x0b\x32\x35.cosmos.orm.v1alpha1.ModuleSchemaDescriptor.FileEntry\x12\x0e\n\x06prefix\x18\x02 \x01(\x0c\x1ah\n\tFileEntry\x12\n\n\x02id\x18\x01 \x01(\r\x12\x17\n\x0fproto_file_name\x18\x02 \x01(\t\x12\x36\n\x0cstorage_type\x18\x03 \x01(\x0e\x32 .cosmos.orm.v1alpha1.StorageType*h\n\x0bStorageType\x12$\n STORAGE_TYPE_DEFAULT_UNSPECIFIED\x10\x00\x12\x17\n\x13STORAGE_TYPE_MEMORY\x10\x01\x12\x1a\n\x16STORAGE_TYPE_TRANSIENT\x10\x02:f\n\rmodule_schema\x12\x1f.google.protobuf.MessageOptions\x18\xf0\xb3\xea\x31 \x01(\x0b\x32+.cosmos.orm.v1alpha1.ModuleSchemaDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.v1alpha1.schema_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STORAGETYPE']._serialized_start=316
  _globals['_STORAGETYPE']._serialized_end=420
  _globals['_MODULESCHEMADESCRIPTOR']._serialized_start=92
  _globals['_MODULESCHEMADESCRIPTOR']._serialized_end=314
  _globals['_MODULESCHEMADESCRIPTOR_FILEENTRY']._serialized_start=210
  _globals['_MODULESCHEMADESCRIPTOR_FILEENTRY']._serialized_end=314
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/abci/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from v4_proto.tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from v4_proto.tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from v4_proto.tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btendermint/abci/types.proto\x12\x0ftendermint.abci\x1a\x1dtendermint/crypto/proof.proto\x1a\x1ctendermint/crypto/keys.proto\x1a\x1dtendermint/types/params.proto\x1a tendermint/types/validator.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\xf2\x07\n\x07Request\x12,\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.RequestEchoH\x00\x12.\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.RequestFlushH\x00\x12,\n\x04info\x18\x03 \x01(\x0b\x32\x1c.tendermint.abci.RequestInfoH\x00\x12\x37\n\ninit_chain\x18\x05 \x01(\x0b\x32!.tendermint.abci.RequestInitChainH\x00\x12.\n\x05query\x18\x06 \x01(\x0b\x32\x1d.tendermint.abci.RequestQueryH\x00\x12\x33\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32\x1f.tendermint.abci.RequestCheckTxH\x00\x12\x30\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1e.tendermint.abci.RequestCommitH\x00\x12?\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32%.tendermint.abci.RequestListSnapshotsH\x00\x12?\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32%.tendermint.abci.RequestOfferSnapshotH\x00\x12H\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32).tendermint.abci.RequestLoadSnapshotChunkH\x00\x12J\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.RequestApplySnapshotChunkH\x00\x12\x43\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32\'.tendermint.abci.RequestPrepareProposalH\x00\x12\x43\n\x10process_proposal\x18\x11 \x01(\x0b\x32\'.tendermint.abci.RequestProcessProposalH\x00\x12\x39\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32\".tendermint.abci.RequestExtendVoteH\x00\x12L\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32+.tendermint.abci.RequestVerifyVoteExtensionH\x00\x12?\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32%.tendermint.abci.RequestFinalizeBlockH\x00\x42\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0cRequestFlush\"`\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\x12\x14\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\t\"\x82\x02\n\x10RequestInitChain\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12;\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32!.tendermint.types.ConsensusParams\x12:\n\nvalidators\x18\x04 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"I\n\x0cRequestQuery\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"H\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tendermint.abci.CheckTxType\"\x0f\n\rRequestCommit\"\x16\n\x14RequestListSnapshots\"U\n\x14RequestOfferSnapshot\x12+\n\x08snapshot\x18\x01 \x01(\x0b\x32\x19.tendermint.abci.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"I\n\x18RequestLoadSnapshotChunk\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r\"I\n\x19RequestApplySnapshotChunk\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\xb6\x02\n\x16RequestPrepareProposal\x12\x14\n\x0cmax_tx_bytes\x18\x01 \x01(\x03\x12\x0b\n\x03txs\x18\x02 \x03(\x0c\x12\x44\n\x11local_last_commit\x18\x03 \x01(\x0b\x32#.tendermint.abci.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00\x12\x37\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\x1c.tendermint.abci.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xa9\x02\n\x16RequestProcessProposal\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12?\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32\x1b.tendermint.abci.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x37\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1c.tendermint.abci.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xa4\x02\n\x11RequestExtendVote\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x32\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x0b\n\x03txs\x18\x04 \x03(\x0c\x12?\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32\x1b.tendermint.abci.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x37\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\x1c.tendermint.abci.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"m\n\x1aRequestVerifyVoteExtension\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x16\n\x0evote_extension\x18\x04 \x01(\x0c\"\xa6\x02\n\x14RequestFinalizeBlock\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12>\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32\x1b.tendermint.abci.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x37\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1c.tendermint.abci.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xbc\x08\n\x08Response\x12\x37\n\texception\x18\x01 \x01(\x0b\x32\".tendermint.abci.ResponseExceptionH\x00\x12-\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.ResponseEchoH\x00\x12/\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1e.tendermint.abci.ResponseFlushH\x00\x12-\n\x04info\x18\x04 \x01(\x0b\x32\x1d.tendermint.abci.ResponseInfoH\x00\x12\x38\n\ninit_chain\x18\x06 \x01(\x0b\x32\".tendermint.abci.ResponseInitChainH\x00\x12/\n\x05query\x18\x07 \x01(\x0b\x32\x1e.tendermint.abci.ResponseQueryH\x00\x12\x34\n\x08\x63heck_tx\x18\t \x01(\x0b\x32 .tendermint.abci.ResponseCheckTxH\x00\x12\x31\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommitH\x00\x12@\n\x0elist_snapshots\x18\r \x01(\x0b\x32&.tendermint.abci.ResponseListSnapshotsH\x00\x12@\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32&.tendermint.abci.ResponseOfferSnapshotH\x00\x12I\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.ResponseLoadSnapshotChunkH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32+.tendermint.abci.ResponseApplySnapshotChunkH\x00\x12\x44\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32(.tendermint.abci.ResponsePrepareProposalH\x00\x12\x44\n\x10process_proposal\x18\x12 \x01(\x0b\x32(.tendermint.abci.ResponseProcessProposalH\x00\x12:\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32#.tendermint.abci.ResponseExtendVoteH\x00\x12M\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32,.tendermint.abci.ResponseVerifyVoteExtensionH\x00\x12@\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32&.tendermint.abci.ResponseFinalizeBlockH\x00\x42\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\"\n\x11ResponseException\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rResponseFlush\"z\n\x0cResponseInfo\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\"\x9e\x01\n\x11ResponseInitChain\x12;\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32!.tendermint.types.ConsensusParams\x12:\n\nvalidators\x18\x02 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\xb6\x01\n\rResponseQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12.\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1b.tendermint.crypto.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"\x80\x02\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\tJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"3\n\x0eResponseCommit\x12\x15\n\rretain_height\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"E\n\x15ResponseListSnapshots\x12,\n\tsnapshots\x18\x01 \x03(\x0b\x32\x19.tendermint.abci.Snapshot\"\xb6\x01\n\x15ResponseOfferSnapshot\x12=\n\x06result\x18\x01 \x01(\x0e\x32-.tendermint.abci.ResponseOfferSnapshot.Result\"^\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\n\n\x06REJECT\x10\x03\x12\x11\n\rREJECT_FORMAT\x10\x04\x12\x11\n\rREJECT_SENDER\x10\x05\"*\n\x19ResponseLoadSnapshotChunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\xf2\x01\n\x1aResponseApplySnapshotChunk\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.tendermint.abci.ResponseApplySnapshotChunk.Result\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t\"`\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x12\n\x0eRETRY_SNAPSHOT\x10\x04\x12\x13\n\x0fREJECT_SNAPSHOT\x10\x05\"&\n\x17ResponsePrepareProposal\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"\x99\x01\n\x17ResponseProcessProposal\x12G\n\x06status\x18\x01 \x01(\x0e\x32\x37.tendermint.abci.ResponseProcessProposal.ProposalStatus\"5\n\x0eProposalStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\",\n\x12ResponseExtendVote\x12\x16\n\x0evote_extension\x18\x01 \x01(\x0c\"\x9d\x01\n\x1bResponseVerifyVoteExtension\x12I\n\x06status\x18\x01 \x01(\x0e\x32\x39.tendermint.abci.ResponseVerifyVoteExtension.VerifyStatus\"3\n\x0cVerifyStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\"\xa5\x02\n\x15ResponseFinalizeBlock\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x31\n\ntx_results\x18\x02 \x03(\x0b\x32\x1d.tendermint.abci.ExecTxResult\x12\x41\n\x11validator_updates\x18\x03 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x42\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32!.tendermint.types.ConsensusParams\x12\x10\n\x08\x61pp_hash\x18\x05 \x01(\x0c\"K\n\nCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12.\n\x05votes\x18\x02 \x03(\x0b\x32\x19.tendermint.abci.VoteInfoB\x04\xc8\xde\x1f\x00\"[\n\x12\x45xtendedCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12\x36\n\x05votes\x18\x02 \x03(\x0b\x32!.tendermint.abci.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00\"h\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Q\n\nattributes\x18\x02 \x03(\x0b\x32\x1f.tendermint.abci.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x08\"\xd6\x01\n\x0c\x45xecTxResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"j\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x33\n\x06result\x18\x04 \x01(\x0b\x32\x1d.tendermint.abci.ExecTxResultB\x04\xc8\xde\x1f\x00\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"U\n\x0fValidatorUpdate\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\r\n\x05power\x18\x02 \x01(\x03\"{\n\x08VoteInfo\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x34\n\rblock_id_flag\x18\x03 \x01(\x0e\x32\x1d.tendermint.types.BlockIDFlagJ\x04\x08\x02\x10\x03\"\xb8\x01\n\x10\x45xtendedVoteInfo\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x16\n\x0evote_extension\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x04 \x01(\x0c\x12\x34\n\rblock_id_flag\x18\x05 \x01(\x0e\x32\x1d.tendermint.types.BlockIDFlagJ\x04\x08\x02\x10\x03\"\xd2\x01\n\x0bMisbehavior\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .tendermint.abci.MisbehaviorType\x12\x33\n\tvalidator\x18\x02 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*9\n\x0b\x43heckTxType\x12\x10\n\x03NEW\x10\x00\x1a\x07\x8a\x9d \x03New\x12\x18\n\x07RECHECK\x10\x01\x1a\x0b\x8a\x9d \x07Recheck*K\n\x0fMisbehaviorType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\x9d\x0b\n\x04\x41\x42\x43I\x12\x43\n\x04\x45\x63ho\x12\x1c.tendermint.abci.RequestEcho\x1a\x1d.tendermint.abci.ResponseEcho\x12\x46\n\x05\x46lush\x12\x1d.tendermint.abci.RequestFlush\x1a\x1e.tendermint.abci.ResponseFlush\x12\x43\n\x04Info\x12\x1c.tendermint.abci.RequestInfo\x1a\x1d.tendermint.abci.ResponseInfo\x12L\n\x07\x43heckTx\x12\x1f.tendermint.abci.RequestCheckTx\x1a .tendermint.abci.ResponseCheckTx\x12\x46\n\x05Query\x12\x1d.tendermint.abci.RequestQuery\x1a\x1e.tendermint.abci.ResponseQuery\x12I\n\x06\x43ommit\x12\x1e.tendermint.abci.RequestCommit\x1a\x1f.tendermint.abci.ResponseCommit\x12R\n\tInitChain\x12!.tendermint.abci.RequestInitChain\x1a\".tendermint.abci.ResponseInitChain\x12^\n\rListSnapshots\x12%.tendermint.abci.RequestListSnapshots\x1a&.tendermint.abci.ResponseListSnapshots\x12^\n\rOfferSnapshot\x12%.tendermint.abci.RequestOfferSnapshot\x1a&.tendermint.abci.ResponseOfferSnapshot\x12j\n\x11LoadSnapshotChunk\x12).tendermint.abci.RequestLoadSnapshotChunk\x1a*.tendermint.abci.ResponseLoadSnapshotChunk\x12m\n\x12\x41pplySnapshotChunk\x12*.tendermint.abci.RequestApplySnapshotChunk\x1a+.tendermint.abci.ResponseApplySnapshotChunk\x12\x64\n\x0fPrepareProposal\x12\'.tendermint.abci.RequestPrepareProposal\x1a(.tendermint.abci.ResponsePrepareProposal\x12\x64\n\x0fProcessProposal\x12\'.tendermint.abci.RequestProcessProposal\x1a(.tendermint.abci.ResponseProcessProposal\x12U\n\nExtendVote\x12\".tendermint.abci.RequestExtendVote\x1a#.tendermint.abci.ResponseExtendVote\x12p\n\x13VerifyVoteExtension\x12+.tendermint.abci.RequestVerifyVoteExtension\x1a,.tendermint.abci.ResponseVerifyVoteExtension\x12^\n\rFinalizeBlock\x12%.tendermint.abci.RequestFinalizeBlock\x1a&.tendermint.abci.ResponseFinalizeBlockB)Z\'github.com/cometbft/cometbft/abci/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.abci.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/cometbft/cometbft/abci/types'
  _globals['_CHECKTXTYPE'].values_by_name["NEW"]._loaded_options = None
  _globals['_CHECKTXTYPE'].values_by_name["NEW"]._serialized_options = b'\212\235 \003New'
  _globals['_CHECKTXTYPE'].values_by_name["RECHECK"]._loaded_options = None
  _globals['_CHECKTXTYPE'].values_by_name["RECHECK"]._serialized_options = b'\212\235 \007Recheck'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_VALIDATORUPDATE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_VALIDATORUPDATE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CHECKTXTYPE']._serialized_start=8001
  _globals['_CHECKTXTYPE']._serialized_end=8058
  _globals['_MISBEHAVIORTYPE']._serialized_start=8060
  _globals['_MISBEHAVIORTYPE']._serialized_end=8135
  _globals['_REQUEST']._serialized_start=230
  _globals['_REQUEST']._serialized_end=1240
  _globals['_REQUESTECHO']._serialized_start=1242
  _globals['_REQUESTECHO']._serialized_end=1272
  _globals['_REQUESTFLUSH']._serialized_start=1274
  _globals['_REQUESTFLUSH']._serialized_end=1288
  _globals['_REQUESTINFO']._serialized_start=1290
  _globals['_REQUESTINFO']._serialized_end=1386
  _globals['_REQUESTINITCHAIN']._serialized_start=1389
  _globals['_REQUESTINITCHAIN']._serialized_end=1647
  _globals['_REQUESTQUERY']._serialized_start=1649
  _globals['_REQUESTQUERY']._serialized_end=1722
  _globals['_REQUESTCHECKTX']._serialized_start=1724
  _globals['_REQUESTCHECKTX']._serialized_end=1796
  _globals['_REQUESTCOMMIT']._serialized_start=1798
  _globals['_REQUESTCOMMIT']._serialized_end=1813
  _globals['_REQUESTLISTSNAPSHOTS']._serialized_start=1815
  _globals['_REQUESTLISTSNAPSHOTS']._serialized_end=1837
  _globals['_REQUESTOFFERSNAPSHOT']._serialized_start=1839
  _globals['_REQUESTOFFERSNAPSHOT']._serialized_end=1924
  _globals['_REQUESTLOADSNAPSHOTCHUNK']._serialized_start=1926
  _globals['_REQUESTLOADSNAPSHOTCHUNK']._serialized_end=1999
  _globals['_REQUESTAPPLYSNAPSHOTCHUNK']._serialized_start=2001
  _globals['_REQUESTAPPLYSNAPSHOTCHUNK']._serialized_end=2074
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_start=2077
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_end=2387
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_start=2390
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_end=2687
  _globals['_REQUESTEXTENDVOTE']._serialized_start=2690
  _globals['_REQUESTEXTENDVOTE']._serialized_end=2982
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_start=2984
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_end=3093
  _globals['_REQUESTFINALIZEBLOCK']._serialized_start=3096
  _globals['_REQUESTFINALIZEBLOCK']._serialized_end=3390
  _globals['_RESPONSE']._serialized_start=3393
  _globals['_RESPONSE']._serialized_end=4477
  _globals['_RESPONSEEXCEPTION']._serialized_start=4479
  _globals['_RESPONSEEXCEPTION']._serialized_end=4513
  _globals['_RESPONSEECHO']._serialized_start=4515
  _globals['_RESPONSEECHO']._serialized_end=4546
  _globals['_RESPONSEFLUSH']._serialized_start=4548
  _globals['_RESPONSEFLUSH']._serialized_end=4563
  _globals['_RESPONSEINFO']._serialized_start=4565
  _globals['_RESPONSEINFO']._serialized_end=4687
  _globals['_RESPONSEINITCHAIN']._serialized_start=4690
  _globals['_RESPONSEINITCHAIN']._serialized_end=4848
  _globals['_RESPONSEQUERY']._serialized_start=4851
  _globals['_RESPONSEQUERY']._serialized_end=5033
  _globals['_RESPONSECHECKTX']._serialized_start=5036
  _globals['_RESPONSECHECKTX']._serialized_end=5292
  _globals['_RESPONSECOMMIT']._serialized_start=5294
  _globals['_RESPONSECOMMIT']._serialized_end=5345
  _globals['_RESPONSELISTSNAPSHOTS']._serialized_start=5347
  _globals['_RESPONSELISTSNAPSHOTS']._serialized_end=5416
  _globals['_RESPONSEOFFERSNAPSHOT']._serialized_start=5419
  _globals['_RESPONSEOFFERSNAPSHOT']._serialized_end=5601
  _globals['_RESPONSEOFFERSNAPSHOT_RESULT']._serialized_start=5507
  _globals['_RESPONSEOFFERSNAPSHOT_RESULT']._serialized_end=5601
  _globals['_RESPONSELOADSNAPSHOTCHUNK']._serialized_start=5603
  _globals['_RESPONSELOADSNAPSHOTCHUNK']._serialized_end=5645
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK']._serialized_start=5648
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK']._serialized_end=5890
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT']._serialized_start=5794
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT']._serialized_end=5890
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_start=5892
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_end=5930
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_start=5933
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_end=6086
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_start=6033
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_end=6086
  _globals['_RESPONSEEXTENDVOTE']._serialized_start=6088
  _globals['_RESPONSEEXTENDVOTE']._serialized_end=6132
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_start=6135
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_end=6292
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_start=6241
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_end=6292
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_start=6295
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_end=6588
  _globals['_COMMITINFO']._serialized_start=6590
  _globals['_COMMITINFO']._serialized_end=6665
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=6667
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6758
  _globals['_EVENT']._serialized_start=6760
  _globals['_EVENT']._serialized_end=6864
  _globals['_EVENTATTRIBUTE']._serialized_start=6866
  _globals['_EVENTATTRIBUTE']._serialized_end=6925
  _globals['_EXECTXRESULT']._serialized_start=6928
  _globals['_EXECTXRESULT']._serialized_end=7142
  _globals['_TXRESULT']._serialized_start=7144
  _globals['_TXRESULT']._serialized_end=7250
  _globals['_VALIDATOR']._serialized_start=7252
  _globals['_VALIDATOR']._serialized_end=7295
  _globals['_VALIDATORUPDATE']._serialized_start=7297
  _globals['_VALIDATORUPDATE']._serialized_end=7382
  _globals['_VOTEINFO']._serialized_start=7384
  _globals['_VOTEINFO']._serialized_end=7507
  _globals['_EXTENDEDVOTEINFO']._serialized_start=7510
  _globals['_EXTENDEDVOTEINFO']._serialized_end=7694
  _globals['_MISBEHAVIOR']._serialized_start=7697
  _globals['_MISBEHAVIOR']._serialized_end=7907
  _globals['_SNAPSHOT']._serialized_start=7909
  _globals['_SNAPSHOT']._serialized_end=7999
  _globals['_ABCI']._serialized_start=8138
  _globals['_ABCI']._serialized_end=9575
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("gen_txs",)
    GEN_TXS_FIELD_NUMBER: _ClassVar[int]
    gen_txs: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, gen_txs: _Optional[_Iterable[bytes]] = ...) -> None: ...



from setuptools import find_namespace_packages, setup

with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name="v4-proto",
    version="5.2.2",
    author="dYdX Trading Inc.",
    author_email="contact@dydx.exchange",
    description="Protos for dYdX Chain protocol",
    packages = find_namespace_packages(),
    include_package_data=True,  # Include files specified in MANIFEST.in
    install_requires=required,
    license_files = ("LICENSE"),
    python_requires=">=3.8",
)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.mint.v1beta1 import mint_pb2 as _mint_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _mint_pb2.Params
    def __init__(self, params: _Optional[_Union[_mint_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryInflationRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryInflationResponse(_message.Message):
    __slots__ = ("inflation",)
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    inflation: bytes
    def __init__(self, inflation: _Optional[bytes] = ...) -> None: ...

class QueryAnnualProvisionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryAnnualProvisionsResponse(_message.Message):
    __slots__ = ("annual_provisions",)
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    annual_provisions: bytes
    def __init__(self, annual_provisions: _Optional[bytes] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EventSend(_message.Message):
    __slots__ = ("class_id", "id", "sender", "receiver")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    sender: str
    receiver: str
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ..., sender: _Optional[str] = ..., receiver: _Optional[str] = ...) -> None: ...

class EventMint(_message.Message):
    __slots__ = ("class_id", "id", "owner")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    owner: str
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ..., owner: _Optional[str] = ...) -> None: ...

class EventBurn(_message.Message):
    __slots__ = ("class_id", "id", "owner")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    owner: str
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ..., owner: _Optional[str] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IndexerSubaccountId(_message.Message):
    __slots__ = ("owner", "number")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    owner: str
    number: int
    def __init__(self, owner: _Optional[str] = ..., number: _Optional[int] = ...) -> None: ...

class IndexerPerpetualPosition(_message.Message):
    __slots__ = ("perpetual_id", "quantums", "funding_index", "funding_payment")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    FUNDING_INDEX_FIELD_NUMBER: _ClassVar[int]
    FUNDING_PAYMENT_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    quantums: bytes
    funding_index: bytes
    funding_payment: bytes
    def __init__(self, perpetual_id: _Optional[int] = ..., quantums: _Optional[bytes] = ..., funding_index: _Optional[bytes] = ..., funding_payment: _Optional[bytes] = ...) -> None: ...

class IndexerAssetPosition(_message.Message):
    __slots__ = ("asset_id", "quantums", "index")
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    asset_id: int
    quantums: bytes
    index: int
    def __init__(self, asset_id: _Optional[int] = ..., quantums: _Optional[bytes] = ..., index: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/v1beta1/vesting.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/vesting/v1beta1/vesting.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\x82\x04\n\x12\x42\x61seVestingAccount\x12<\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01\x12{\n\x10original_vesting\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12y\n\x0e\x64\x65legated_free\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12|\n\x11\x64\x65legated_vesting\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\x03:&\x88\xa0\x1f\x00\x8a\xe7\xb0*\x1d\x63osmos-sdk/BaseVestingAccount\"\xac\x01\n\x18\x43ontinuousVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12\x12\n\nstart_time\x18\x02 \x01(\x03:,\x88\xa0\x1f\x00\x8a\xe7\xb0*#cosmos-sdk/ContinuousVestingAccount\"\x92\x01\n\x15\x44\x65layedVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:)\x88\xa0\x1f\x00\x8a\xe7\xb0* cosmos-sdk/DelayedVestingAccount\"\x8b\x01\n\x06Period\x12\x0e\n\x06length\x18\x01 \x01(\x03\x12q\n\x06\x61mount\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\"\xec\x01\n\x16PeriodicVestingAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x42\n\x0fvesting_periods\x18\x03 \x03(\x0b\x32\x1e.cosmos.vesting.v1beta1.PeriodB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:*\x88\xa0\x1f\x00\x8a\xe7\xb0*!cosmos-sdk/PeriodicVestingAccount\"\x94\x01\n\x16PermanentLockedAccount\x12N\n\x14\x62\x61se_vesting_account\x18\x01 \x01(\x0b\x32*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:*\x88\xa0\x1f\x00\x8a\xe7\xb0*!cosmos-sdk/PermanentLockedAccountB3Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.vesting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['original_vesting']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['original_vesting']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_free']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_free']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_vesting']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT'].fields_by_name['delegated_vesting']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_BASEVESTINGACCOUNT']._loaded_options = None
  _globals['_BASEVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\212\347\260*\035cosmos-sdk/BaseVestingAccount'
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_CONTINUOUSVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_CONTINUOUSVESTINGACCOUNT']._loaded_options = None
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\212\347\260*#cosmos-sdk/ContinuousVestingAccount'
  _globals['_DELAYEDVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_DELAYEDVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_DELAYEDVESTINGACCOUNT']._loaded_options = None
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\212\347\260* cosmos-sdk/DelayedVestingAccount'
  _globals['_PERIOD'].fields_by_name['amount']._loaded_options = None
  _globals['_PERIOD'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PERIODICVESTINGACCOUNT']._loaded_options = None
  _globals['_PERIODICVESTINGACCOUNT']._serialized_options = b'\210\240\037\000\212\347\260*!cosmos-sdk/PeriodicVestingAccount'
  _globals['_PERMANENTLOCKEDACCOUNT'].fields_by_name['base_vesting_account']._loaded_options = None
  _globals['_PERMANENTLOCKEDACCOUNT'].fields_by_name['base_vesting_account']._serialized_options = b'\320\336\037\001'
  _globals['_PERMANENTLOCKEDACCOUNT']._loaded_options = None
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_options = b'\210\240\037\000\212\347\260*!cosmos-sdk/PermanentLockedAccount'
  _globals['_BASEVESTINGACCOUNT']._serialized_start=170
  _globals['_BASEVESTINGACCOUNT']._serialized_end=684
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_start=687
  _globals['_CONTINUOUSVESTINGACCOUNT']._serialized_end=859
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_start=862
  _globals['_DELAYEDVESTINGACCOUNT']._serialized_end=1008
  _globals['_PERIOD']._serialized_start=1011
  _globals['_PERIOD']._serialized_end=1150
  _globals['_PERIODICVESTINGACCOUNT']._serialized_start=1153
  _globals['_PERIODICVESTINGACCOUNT']._serialized_end=1389
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_start=1392
  _globals['_PERMANENTLOCKEDACCOUNT']._serialized_end=1540
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.nft.v1beta1 import nft_pb2 as _nft_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("classes", "entries")
    CLASSES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    classes: _containers.RepeatedCompositeFieldContainer[_nft_pb2.Class]
    entries: _containers.RepeatedCompositeFieldContainer[Entry]
    def __init__(self, classes: _Optional[_Iterable[_Union[_nft_pb2.Class, _Mapping]]] = ..., entries: _Optional[_Iterable[_Union[Entry, _Mapping]]] = ...) -> None: ...

class Entry(_message.Message):
    __slots__ = ("owner", "nfts")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NFTS_FIELD_NUMBER: _ClassVar[int]
    owner: str
    nfts: _containers.RepeatedCompositeFieldContainer[_nft_pb2.NFT]
    def __init__(self, owner: _Optional[str] = ..., nfts: _Optional[_Iterable[_Union[_nft_pb2.NFT, _Mapping]]] = ...) -> None: ...
